@@ -1,9 +1,6 @@
-
-#include "strutil.h"
 #include "editor.h"
-#include "editorcmd.h"
 
-using namespace strutil;
+using namespace MLSUTIL;
 using namespace MLS;
 
 void	Editor::Key_Home()
@@ -297,7 +294,7 @@ void 	Editor::Copy()
 
 	if (_EditSelect.y2 >= _vText.size())
 	{
-		LOG("Error :: _EditSelect.y2 > _vText.size ");
+		g_Log.Write("Error :: _EditSelect.y2 > _vText.size ");
 		return;
 	}
 
@@ -329,7 +326,7 @@ void 	Editor::Copy()
 		}
 	}
 	
-	_Clip.Set(vWStr, Edit_ClipCopy);
+	g_tEditorClip.Set(vWStr, Edit_ClipCopy);
 	_EditMode = EDIT;
 }
 
@@ -343,7 +340,7 @@ void	Editor::Selected_Del()
 
 	if (_EditSelect.y2 >= _vText.size())
 	{
-		LOG("Error :: _EditSelect.y2 > _vText.size ");
+		g_Log.Write("Error :: _EditSelect.y2 > _vText.size ");
 		_EditMode = EDIT;
 		return;
 	}
@@ -412,7 +409,7 @@ void 	Editor::Cut()
 
 	if (_EditSelect.y2 >= _vText.size())
 	{
-		LOG("Error :: _EditSelect.y2 > _vText.size ");
+		g_Log.Write("Error :: _EditSelect.y2 > _vText.size ");
 		_EditMode = EDIT;
 		return;
 	}
@@ -444,7 +441,7 @@ void 	Editor::Cut()
 			vWStr.push_back(WStr);
 		}
 	}
-	_Clip.Set(vWStr, Edit_ClipCut);
+	g_tEditorClip.Set(vWStr, Edit_ClipCut);
 	
 	Selected_Del();
 	_nCurCulumn_Max = _nCurCulumn;
@@ -459,8 +456,8 @@ void 	Editor::Paste()
 	wstring				WStr, WStr1, WStr2;
 	wstring				WClip, WClip2;
 
-	vClip = _Clip.Get();
-	LOG("ClipSize :: [%d]", vClip.size());
+	vClip = g_tEditorClip.Get();
+	g_Log.Write("ClipSize :: [%d]", vClip.size());
 
 	if (_EditMode != EDIT)	Selected_Del();
 
@@ -528,7 +525,7 @@ void	Editor::Undo()
 	
 	if (pDoInfo == NULL)
 	{
-		LOG("Undo pDoInfo NULL !!!");
+		g_Log.Write("Undo pDoInfo NULL !!!");
 		return;
 	}
 
@@ -591,167 +588,116 @@ void	Editor::Undo()
 }
 
 
-void	Editor::Key_Mouse()
-{
-	MEVENT event;
-	getmouse(&event);
-
-	LOG("Event.x [%d] Event.y [%d] Event [%u]",event.x, event.y, event.bstate);
-
-	if (BUTTON_CLICK(event.bstate,1)) _shutdown = true;	
-}
-
-void	Editor::Menu()
-{
-	vector<string>	vDisableCmd;
-
-	if (_bReadOnly == true)
-	{
-		vDisableCmd.push_back("<filenew>");
-		vDisableCmd.push_back("<filesave>");		
-		vDisableCmd.push_back("<paste>");
-	}
-
-	if (_vDoInfo.size() == 0)
-		vDisableCmd.push_back("<undo>");
-
-	EditorMenu	tEditorMenu;
-	tEditorMenu.SetDisable(vDisableCmd);
-	tEditorMenu.Create();						// 메뉴 만들기
-	g_pEditorCmd->Execute(tEditorMenu.Process(&_tEditKeyBind));
-	Refresh();
-}
-
 void	Editor::FileNew()
 {
 	if (_bReadOnly == true)
 	{
-		MsgBox(gettext("Error"), gettext("Read only file loaded."));
+		MsgBox(_("Error"), _("Read only file loaded."));
 		return;
 	}
 
 	// 변동이 있으면 현재 파일을 저장할지 물어본다.
 	if (_nConvInfo != _vDoInfo.size())
 	{
-		if (YNBox(gettext("New file. Do you want to save ?"), YN_Y) == YN_Y)
+		if (YNBox(_("File New"), _("New file. Do you want to save ?"), true) == true)
 		{
 			FileSave();
 		}
 	}
 
 	string sFilename;
-	if (InputBox("New File...", sFilename) == 0) return;
+	if (InputBox("New File...", sFilename) == ERROR) return;
 	if (sFilename.size() == 0)	return;
 
 	ifstream in(sFilename.c_str());
 	if (in)
 	{
-		MsgBox(gettext("Error"), gettext("current file using."));
+		MsgBox(_("Error"), _("current file using."));
 		return;
 	}
 	
 	New(sFilename);
-	SetTitle("["+sFilename+"]");
+	SetViewTitle("["+sFilename+"]");
 }
 
-void	Editor::FileSave()
+bool	Editor::FileSave()
 {
 	if (_bReadOnly == true)
 	{
-		MsgBox(gettext("Error"), gettext("This file read only."));
-		return;
+		MsgBox(_("Error"), _("This file read only."));
+		return false;
 	}
 	if (Save(_sFile, AUTO, _bDosMode, _bBackup) == true)
 	{
 		_nConvInfo = _vDoInfo.size(); // 저장 시점 저장. 저장 여부판단.
+		return true;
 	}
+	return false;
 }
 
-void	Editor::FileSaveAs()
+bool	Editor::FileSaveAs()
 {
-	string sFilename = _sFile;
+	string 		sFilename;
+	string 		sPath;
 
-	if (InputBox("Save as", sFilename) == 0) return;
-	if (sFilename.size() == 0)	return;
+	string::size_type	p = _sFile.rfind("/");
+
+	if (p != string::npos)
+	{
+		sPath = _sFile.substr( 0, p+1 );
+		sFilename = _sFile.substr( p+1 );
+	}
+	else
+	{
+		sFilename = _sFile;
+	}
+
+	if (InputBox("Save as", sFilename) == ERROR) return false;
+	if (sFilename.size() == 0)	return false;
 
 	vector<string>	vStr;
-	vStr.push_back(strmid(16, gettext("Current Encode")));
-	vStr.push_back(strmid(15, gettext("EUC-KR")));
-	vStr.push_back(strmid(15, gettext("UTF-8")));
+	vStr.push_back(strmid(16, _("Current Encode")));
+	vStr.push_back(strmid(15, _("EUC-KR")));
+	vStr.push_back(strmid(15, _("UTF-8")));
 	if (_bDosMode)
-		vStr.push_back(strmid(15, gettext("UNIX Mode")));
+		vStr.push_back(strmid(15, _("UNIX Mode")));
 	else
-		vStr.push_back(strmid(15, gettext("DOS Mode")));
-	vStr.push_back(strmid(15, gettext("Cancel")));
+		vStr.push_back(strmid(15, _("DOS Mode")));
+	vStr.push_back(strmid(15, _("Cancel")));
 
-	ListBox tListBox(gettext("Encoding convert."), 0, COLOR_YELLOW);
-	tListBox.SetItem(vStr);
-	int nCho = tListBox.Do();
+	int nCho = SelectBox(_("Encoding convert."), vStr, 0);
 
 	switch(nCho)
 	{
+		case -1:
+			return false;
+			break;
 		case 0:
-			if (Save(sFilename, AUTO, _bDosMode) == true)
+			if (Save(sPath+sFilename, AUTO, _bDosMode) == true)
 				_nConvInfo = _vDoInfo.size(); // 저장 시점 저장
 			break;
 		case 1:
-			if (Save(sFilename, KO_EUCKR, _bDosMode) == true)
+			if (Save(sPath+sFilename, KO_EUCKR, _bDosMode) == true)
 				_nConvInfo = _vDoInfo.size(); // 저장 시점 저장
 			break;
 		case 2:
-			if (Save(sFilename, KO_UTF8, _bDosMode) == true)
+			if (Save(sPath+sFilename, KO_UTF8, _bDosMode) == true)
 				_nConvInfo = _vDoInfo.size(); // 저장 시점 저장
 			break;
 		case 3:
-			if (Save(sFilename, AUTO, !_bDosMode) == true)
+			if (Save(sPath+sFilename, AUTO, !_bDosMode) == true)
 				_nConvInfo = _vDoInfo.size(); // 저장 시점 저장
 		case 4:
-			return;
-	}
-	SetTitle("["+sFilename+"]");
-}
-
-void	Editor::Exit()
-{
-	vector<string>	vStr;
-	vStr.push_back(strmid(10, gettext("Yes")));
-	vStr.push_back(strmid(10, gettext("No")));
-
-	if (_bReadOnly == true)
-	{
-		_shutdown = true;
-		return;
-	}
-	
-	// 변동이 있으면 현재 파일을 저장할지 물어본다.
-	if (_nConvInfo != _vDoInfo.size())
-	{
-		vStr.push_back(strmid(10, gettext("Cancel")));
-
-		int nCho = SelectBox(gettext("Editor exit. Do you want to save ?"), vStr, 2);
-
-		switch(nCho)
-		{
-			case 0:
-				FileSave();
-			case 1:
-				_shutdown = true;
-				break;
-		}
-		return;
-	}
-	else
-	{
-		// 이건 토의 해야 할건. - 빠져나갈때 물어보는가? 
-		//if (SelectBox(gettext("Do you want to editor exit?"), vStr, 0) == 0)
-			_shutdown = true;
+			return false;
 	}
+	SetViewTitle("["+sFilename+"]");
+	return true;
 }
 
 void	Editor::Find()
 {
 	string	sFind = wstrtostr(_sFindStr);
-	if (InputBox(gettext("Find Text."), sFind) == -1) return;
+	if (InputBox(_("Find Text."), sFind) == ERROR) return;
 	if (sFind.size() == 0) return;
 	_sFindStr = strtowstr(sFind);
 	_nFindPosX = 0;
@@ -794,7 +740,9 @@ void	Editor::FindNext()
 			_nFindPosX = 0;
 		}
 		_nFindPosY= 0;
-		if (YNBox(gettext("End of document reached. Continue from the begining?"), YN_Y) == YN_N)
+		if (YNBox(	_("FindNext"), 
+					_("End of document reached. Continue from the begining?"), 
+					true) == false)
 			break;
 	}
 }
@@ -839,77 +787,10 @@ void	Editor::FindPrevious()
 				_nFindPosX = _vText[n-1].size();
 		}
 		_nFindPosY= _vText.size()-1;
-		if (YNBox(gettext("First of document reached. Continue from the begining?"), YN_Y) == YN_N)
+		if (YNBox(	_("FindPrevious"),
+					_("First of document reached. Continue from the begining?"), 
+					true) == false)
 			break;
 	}
 }
 
-void	Editor::Help()
-{
-	vector<string>		vMsgData;
-	string	sKeyName, sMsg;
-
-	vMsgData.push_back("-------------------------------------------------------");
-	vMsgData.push_back("Function Key List");
-	vMsgData.push_back("");
-	for (int nKey = 0; nKey < 12; nKey++)
-	{
-		sMsg = "    F" + strutil::itoa(nKey+1) + " : ";
-		sKeyName = _tEditKeyBind.GetFuncKey(nKey+1);
-		if (sKeyName == "") continue;
-		sMsg = sMsg + gettext(_tEditKeyBind.GetHelpCmd(sKeyName).c_str());
-		vMsgData.push_back(sMsg);
-	}	
-	vMsgData.push_back("");
-	vMsgData.push_back("-------------------------------------------------------");
-	vMsgData.push_back("Meta Key List");
-	vMsgData.push_back("");
-	for (int nKey = 'A'; nKey < 'Z'; nKey++)
-	{
-		sKeyName = _tEditKeyBind.GetHelpMetaKey(nKey);
-		if (sKeyName != "")
-		{
-			sMsg = "Alt+";
-			sMsg.append(1, (char)nKey);
-			sMsg = "    " + sMsg + " : " + gettext(sKeyName.c_str());
-			vMsgData.push_back(sMsg);
-		}
-	}
-
-	vMsgData.push_back("");
-	vMsgData.push_back("-------------------------------------------------------");
-	vMsgData.push_back("Control Key List");
-	vMsgData.push_back("");
-	for (int nKey = 1; nKey < 33; nKey++)
-	{
-		sKeyName = _tEditKeyBind.GetHelpKey(nKey);
-		if (sKeyName != "")
-		{
-			switch(nKey)
-			{
-				case 13: sMsg = "";	break;
-				case 27: sMsg = "";	break;
-				case 9:  sMsg = "";	break;
-				case 32: sMsg = "";	break;
-				default:
-					sMsg = "Ctrl+";
-					sMsg.append(1, (char)((nKey+'A')-1));
-			}
-			if (sMsg != "")
-			{
-				sMsg = "    " + sMsg + " : " + gettext(sKeyName.c_str());
-				vMsgData.push_back(sMsg);
-			}
-		}
-	}
-
-	vMsgData.push_back("");
-	vMsgData.push_back("-------------------------------------------------------");
-	
-	TextBox		tTextBox(gettext("Help"), g_nLINES-6, 50);
-	tTextBox.SetBackColor(COLOR_GREEN);
-	tTextBox.SetFontColor(15);
-	tTextBox.SetText(vMsgData);
-	tTextBox.Do();
-}
-
